==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/th.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "จัดการพารามิเตอร์ Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "จัดการแกลลอรี่");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size ความกว้างของภาพ");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size ความสูงของภาพ");
define('MANAGE_GALLERY_THUMB_WIDTH', "ความกว้างของภาพ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "ไม่มีรูปขนาดความสูง");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "รักษา Thumb อัตราส่วน");
define('MANAGE_GALLERY_SHOW_TITLES', "แสดงชื่อ");
define('MANAGE_GALLERY_DISABLE_SORT', "ปิดการใช้งานเรียง");
define('MANAGE_GALLERY_DELETE_IMAGE', "ลบภาพ");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "บันทึกเรียง");
define('MANAGE_GALLERY_PUBLISH_MSG', "คลิก &#39;อัปเดต &quot;ที่จะเผยแพร่ <br /> ภาพที่คุณอัปโหลด");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "ภาพทุกภาพที่ได้รับการปรับขนาดและการตั้งค่าได้รับการบันทึก");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "มีข้อผิดพลาดการปรับขนาดภาพหรือบันทึกการตั้งค่าเป็น");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "ภาพของคุณ (s) ได้รับการอัปโหลด");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "เกิดข้อผิดพลาดในการอัปโหลดภาพของคุณ (s) เป็น");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ไฟล์ที่คุณกำลังพยายามที่จะอัปโหลดไม่ได้ภาพ");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ไฟล์ที่คุณกำลังพยายามที่จะอัปโหลดมีขนาดใหญ่เกินไป");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "ชื่อที่ได้รับการบันทึกไว้");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "คุณแน่ใจหรือว่าต้องการลบภาพ");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "ภาพที่ถูกลบไปแล้ว");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "เกิดข้อผิดพลาดในการลบภาพ");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "ประหยัดค่าพารามิเตอร์และการปรับขนาดภาพโปรดรอ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "อัปโหลดโปรดรอ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "การเรียงลำดับไม่ได้รับการบันทึกไว้ คุณต้องการที่จะบันทึกการเรียงลำดับ?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ลำดับภาพเรียงลำดับได้รับการบันทึก");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "มีการบันทึกการจัดเรียงภาพที่ผิดพลาด");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/th.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "จัดการพารามิเตอร์ Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "จัดการแกลลอรี่");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size ความกว้างของภาพ");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size ความสูงของภาพ");
define('MANAGE_GALLERY_THUMB_WIDTH', "ความกว้างของภาพ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "ไม่มีรูปขนาดความสูง");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "รักษา Thumb อัตราส่วน");
define('MANAGE_GALLERY_SHOW_TITLES', "แสดงชื่อ");
define('MANAGE_GALLERY_DISABLE_SORT', "ปิดการใช้งานเรียง");
define('MANAGE_GALLERY_DELETE_IMAGE', "ลบภาพ");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "บันทึกเรียง");
define('MANAGE_GALLERY_PUBLISH_MSG', "คลิก &#39;อัปเดต &quot;ที่จะเผยแพร่ <br /> ภาพที่คุณอัปโหลด");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "ภาพทุกภาพที่ได้รับการปรับขนาดและการตั้งค่าได้รับการบันทึก");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "มีข้อผิดพลาดการปรับขนาดภาพหรือบันทึกการตั้งค่าเป็น");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "ภาพของคุณ (s) ได้รับการอัปโหลด");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "เกิดข้อผิดพลาดในการอัปโหลดภาพของคุณ (s) เป็น");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ไฟล์ที่คุณกำลังพยายามที่จะอัปโหลดไม่ได้ภาพ");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ไฟล์ที่คุณกำลังพยายามที่จะอัปโหลดมีขนาดใหญ่เกินไป");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "ชื่อที่ได้รับการบันทึกไว้");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "คุณแน่ใจหรือว่าต้องการลบภาพ");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "ภาพที่ถูกลบไปแล้ว");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "เกิดข้อผิดพลาดในการลบภาพ");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "ประหยัดค่าพารามิเตอร์และการปรับขนาดภาพโปรดรอ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "อัปโหลดโปรดรอ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "การเรียงลำดับไม่ได้รับการบันทึกไว้ คุณต้องการที่จะบันทึกการเรียงลำดับ?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ลำดับภาพเรียงลำดับได้รับการบันทึก");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "มีการบันทึกการจัดเรียงภาพที่ผิดพลาด");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "ไฟล์ที่คุณพยายามอัปโหลดมีขนาดใหญ่กว่าการตั้งค่า PHP &#39;upload_max_filesize&#39; หรือ &#39;post_max_size&#39; ติดต่อผู้ดูแลระบบของคุณเพื่อเพิ่มขีด จำกัด เหล่านี้");
?>
